@@ -1,25 +1,29 @@
-from typing import Dict, Any
+from typing import Dict, Any, Optional
 
 from aiohttp import web as aio_web
+from bolinette_common import paths
 
-from bolinette import core, env, blnt
+from bolinette import core, blnt
 
 
 class BolinetteContext:
-    def __init__(self, app: aio_web.Application):
-        self.app = app
-        self.env = env
-        self.db = core.DatabaseEngine(self)
-        self.jwt = core.JWT()
-        self.resources = core.BolinetteResources(self)
-        self.sockets = core.BolinetteSockets(self)
-        self.mapping = core.Mapping(self)
-        self._tables: Dict[str, Any] = {}
-        self._models: Dict[str, 'blnt.Model'] = {}
-        self._repos: Dict[str, 'blnt.Repository'] = {}
-        self._services: Dict[str, 'blnt.Service'] = {}
-        self._controllers: Dict[str, 'blnt.Controller'] = {}
-        self._ctx = {}
+    def __init__(self, origin: str, app: Optional[aio_web.Application], *, profile=None, overrides=None):
+        self.cwd = paths.cwd()
+        self.origin = origin
+        if app is not None:
+            self.app = app
+            self.env = core.Environment(self, profile=profile, overrides=overrides)
+            self.db = core.DatabaseEngine(self)
+            self.jwt = core.JWT(self)
+            self.resources = core.BolinetteResources(self)
+            self.sockets = core.BolinetteSockets(self)
+            self.mapping = core.Mapping(self)
+            self._tables: Dict[str, Any] = {}
+            self._models: Dict[str, 'blnt.Model'] = {}
+            self._repos: Dict[str, 'blnt.Repository'] = {}
+            self._services: Dict[str, 'blnt.Service'] = {}
+            self._controllers: Dict[str, 'blnt.Controller'] = {}
+            self._ctx = {}
 
     def __getitem__(self, key):
         return self._ctx[key]
@@ -33,6 +37,21 @@ class BolinetteContext:
     def add_model(self, name, model: 'blnt.Model'):
         self._models[name] = model
 
+    def instance_path(self, *path):
+        return self.root_path('instance', *path)
+
+    def env_path(self, *path):
+        return self.root_path('env', *path)
+
+    def static_path(self, *path):
+        return self.root_path('static', *path)
+
+    def root_path(self, *path):
+        return paths.join(self.cwd, *path)
+
+    def internal_path(self, *path):
+        return paths.join(self.origin, *path)
+
     @property
     def models(self):
         return iter(self._models.items())
