@@ -1,3 +1,3 @@
+from bolinette.testing.mock import Mock, Mocked
 from bolinette.testing.client import TestClient
-from bolinette.testing.mock import mock, Mocked
 from bolinette.testing.testing import client, bolitest
